@@ -9,7 +9,7 @@ use Rose::HTML::Util();
 use Rose::HTML::Form::Field;
 our @ISA = qw(Rose::HTML::Form::Field);
 
-our $VERSION = '0.52';
+our $VERSION = '0.542';
 
 our $Debug = undef;
 
@@ -142,6 +142,13 @@ sub _args_to_items
       $item->parent_field($parent);
     }
   }
+  else # If there is no grandparent, at least set the localizer
+  {
+    foreach my $item (@$items)
+    {
+      $item->localizer($self->localizer);
+    }
+  }
 
   return (wantarray) ? @$items : $items;
 }
