@@ -7,7 +7,7 @@ use Rose::HTML::Object::Errors qw(:number);
 use Rose::HTML::Form::Field::Text;
 our @ISA = qw(Rose::HTML::Form::Field::Text);
 
-our $VERSION = '0.54';
+our $VERSION = '0.541';
 
 use Rose::Object::MakeMethods::Generic
 (
@@ -67,6 +67,11 @@ sub validate
   return 1;
 }
 
+if(__PACKAGE__->localizer->auto_load_messages)
+{
+  __PACKAGE__->localizer->load_all_messages;
+}
+
 1;
 
 __DATA__
@@ -79,6 +84,22 @@ NUM_NOT_POSITIVE_INTEGER     = "[label] must be a positive integer."
 NUM_BELOW_MIN                = "[label] must be greater than [value]."
 NUM_ABOVE_MAX                = "[label] must be less than or equal to [value]."
 
+[% LOCALE de %]
+
+NUM_INVALID_INTEGER          = "[label] muß eine Ganzzahl sein."
+NUM_INVALID_INTEGER_POSITIVE = "[label] muß eine positive Ganzzahl sein."
+NUM_NOT_POSITIVE_INTEGER     = "[label] muß eine positive Ganzzahl sein."
+NUM_BELOW_MIN                = "[label] muß größer als [value] sein."
+NUM_ABOVE_MAX                = "[label] muß kleiner oder gleich [value] sein."
+
+[% LOCALE fr %]
+
+NUM_INVALID_INTEGER          = "[label] doit être un entier."
+NUM_INVALID_INTEGER_POSITIVE = "[label] doit être un entier positif."
+NUM_NOT_POSITIVE_INTEGER     = "[label] doit être un entier positif."
+NUM_BELOW_MIN                = "[label] doit être plus grand que [value]."
+NUM_ABOVE_MAX                = "[label] doit être plus petit ou égal à [value]."
+
 __END__
 
 =head1 NAME
